Function library for the identification and separation of exponentially decaying signal components in continuous-wave optically stimulated luminescence (CW-OSL) measurements. A special emphasis is laid on luminescence dating with quartz, which is known for systematic errors due to CW-OSL signal components with unequal physical behaviour. Also, this package enables an easy to use signal decomposition of CW-OSL data sets imported and analysed with the R package 'Luminescence'. This includes the optional automatic creation of HTML reports.
Project website
Source code repository
Bug reporting
This package is part of the RLum.Network
Package maintainer
Dirk Mittelstraß, Independent researcher, Dresden (Germany),
dirk.mittelstrass@luminescence.de
Citation
Please cite this package, including its version number. Enter the command citation("OSLdecomposition") to generate the correct reference.
Funding Dirk Mittelstraß created this package as part of his master thesis and further enhanced and published it as private endeavour. He did not receive any specific grant from funding agencies in the public, commercial or not-for-profit sectors.
Useful links:
Report bugs at https://github.com/DirkMittelstrass/OSLdecomposition/issues