View source: R/check_RLum.Data.R
| check_RLum.Data | R Documentation |
The input object is checked for the following properties:
Is the object of class Luminescence::RLum.Data.Curve ?
Does the objects record type match with this functions argument record_type?
Is the record not just a XSYG metadata object (marked by '_' before the record type name)?
Is the curve of type XY, thus has it a 2 x N dimension?
If a curve_template is provided, the input object is also checked if it matches number of data points, x-axis and the info parameters "LPOWER", "LTYPE" and "TEMPERATURE".
If all checks are positive, the input object is regarded as suitable for the functions RLum.OSL_correction, RLum.OSL_global_fitting, RLum.OSL_decomposition and other functions if their input curve is of type Luminescence::RLum.Data.Curve.
check_RLum.Data(
object,
record_type = "OSL",
curve_template = NULL,
verbose = TRUE
)
object |
Luminescence::RLum.Data.Curve (required): Input object which shall be tested. |
record_type |
character (with default):
Expected type of record of the input |
curve_template |
Luminescence::RLum.Data.Curve (optional): Curve to check x-axis and some measurement parameter against. |
verbose |
logical (with default): Enables console text output. |
A bolean value: TRUE or FALSE.
2026-02-17, DM: Created function.
Dirk Mittelstraß, dirk.mittelstrass@luminescence.de
Please cite this package, including its version number. Enter the command citation("OSLdecomposition") to generate the correct reference.
# Load example data
data_path <- system.file("examples", "FB_10Gy_SAR.bin", package = "OSLdecomposition")
data_set <- Luminescence::read_BIN2R(data_path, fastForward = TRUE)
# Test if record is of type OSL
check_RLum.Data(data_set[[5]]@records[[1]])
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.