- object
Luminescence::RLum.Analysis, or list of Luminescence::RLum.Analysis, Luminescence::RLum.Data.Curve or data.frame (required):
Data set of CW-OSL records.
- record_type
character (with default):
Type of records which are selected from the input object if it is a RLum object,
for example: "OSL","SGOSL" or "IRSL". Does not apply for lists of data.frame.
- selection
numeric vector (optional):
Vector specifying the indices of elements (aliquots) of a list of Luminescence::RLum.Analysis objects
which shall be included.
- Y_offset
numeric (with default):
Signal offset (background) which will be subtracted from each record.
- verbose
logical (with default):
Enables console text output.
- output.plot
logical (with default):
Returns a linear plot as well as a pseudoLM-OSL plot with all data points of all records and the average curve.
- theme.set
ggplot2::ggplot2-package object (with default):
sets the graphical theme of the output plot.
See ggplot2::theme_bw for available themes
- plot.first
logical (with default):
Plot includes additional drawing of first record_type record of first object list element.
- title
character (optional):
Plot title. Set title = "auto" for an automatically generated title.
- filename
character (optional):
File name or path to save the plot as image. If just a file name is given, the image is
saved in the working directory. The image type is chosen by the file ending. Both, vector images
as well as pixel images are possible. Allowed are .pdf, .eps, .svg (vector graphics),
.jpg, .png, .bmp (pixel graphics) and more, see ggplot2::ggsave.